summaryrefslogtreecommitdiff
path: root/src/or/relay.c
diff options
context:
space:
mode:
authorNick Mathewson <nickm@torproject.org>2009-05-27 17:55:51 -0400
committerNick Mathewson <nickm@torproject.org>2009-05-27 17:55:51 -0400
commitec7e0546681f57a1ba1769cca2b8339f9b0dc8b0 (patch)
treeec878942a37b05ee542606c1ee6ebe42c6b43d15 /src/or/relay.c
parentf0453c45c8c3963762b208cfe4f6fb2e1e96cc34 (diff)
downloadtor-ec7e0546681f57a1ba1769cca2b8339f9b0dc8b0.tar.gz
tor-ec7e0546681f57a1ba1769cca2b8339f9b0dc8b0.zip
Spell-check Tor.
Diffstat (limited to 'src/or/relay.c')
-rw-r--r--src/or/relay.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/or/relay.c b/src/or/relay.c
index 937f4ee52d..b47d16a2e4 100644
--- a/src/or/relay.c
+++ b/src/or/relay.c
@@ -7,7 +7,7 @@
/**
* \file relay.c
* \brief Handle relay cell encryption/decryption, plus packaging and
* receiving from circuits, plus queueing on circuits.
**/
#include "or.h"
@@ -783,7 +783,7 @@ connection_ap_process_end_not_open(
"Edge got end (%s) before we're connected. Marking for close.",
stream_end_reason_to_string(rh->length > 0 ? reason : -1));
circuit_log_path(LOG_INFO,LD_APP,circ);
- /* need to test because of detach_retriable*/
+ /* need to test because of detach_retryable*/
if (!conn->_base.marked_for_close)
connection_mark_unattached_ap(conn, control_reason);
return 0;
@@ -1353,7 +1353,7 @@ connection_edge_consider_sending_sendme(edge_connection_t *conn)
while (conn->deliver_window < STREAMWINDOW_START - STREAMWINDOW_INCREMENT) {
log_debug(conn->cpath_layer?LD_APP:LD_EXIT,
- "Outbuf %d, Queueing stream sendme.",
+ "Outbuf %d, Queuing stream sendme.",
(int)conn->_base.outbuf_flushlen);
conn->deliver_window += STREAMWINDOW_INCREMENT;
if (connection_edge_send_command(conn, RELAY_COMMAND_SENDME,
@@ -1467,7 +1467,7 @@ circuit_consider_sending_sendme(circuit_t *circ, crypt_path_t *layer_hint)
// layer_hint ? "defined" : "null");
while ((layer_hint ? layer_hint->deliver_window : circ->deliver_window) <
CIRCWINDOW_START - CIRCWINDOW_INCREMENT) {
- log_debug(LD_CIRC,"Queueing circuit sendme.");
+ log_debug(LD_CIRC,"Queuing circuit sendme.");
if (layer_hint)
layer_hint->deliver_window += CIRCWINDOW_INCREMENT;
else
@@ -7,7 +7,7 @@
* \file relay.c
* \brief Handle relay cell encryption/decryption, plus packaging and
- * receiving from circuits, plus queueing on circuits.
+ * receiving from circuits, plus queuing on circuits.
**/
#include "or.h"